humafiber

package
v2.39.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 29, 2026 License: MIT Imports: 14 Imported by: 11

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(r *fiber.App, config huma.Config) huma.API

New creates a new Huma API using the Fiber adapter.

func NewContext added in v2.39.0

func NewContext(op *huma.Operation, c fiber.Ctx) huma.Context

NewContext creates a new Huma context from a fiber context

func NewV2 added in v2.38.0

func NewV2(r *fiberV2.App, config huma.Config) huma.API

NewV2 creates a new Huma API using the Fiber v2.x adapter.

func NewV2WithGroup added in v2.38.0

func NewV2WithGroup(r *fiberV2.App, g fiberV2.Router, config huma.Config) huma.API

NewV2WithGroup creates a new Huma API using the Fiber v2.x adapter with a route group.

func NewWithGroup added in v2.11.0

func NewWithGroup(r *fiber.App, g fiber.Router, config huma.Config) huma.API

NewWithGroup creates a new Huma API using the Fiber adapter with a route group.

func Unwrap added in v2.30.0

func Unwrap(ctx huma.Context) fiber.Ctx

Unwrap extracts the underlying Fiber context from a Huma context. If passed a context from a different adapter it will panic. Keep in mind the limitations of the underlying Fiber/fasthttp libraries and how that impacts memory-safety: https://docs.gofiber.io/#zero-allocation. Do not keep references to the underlying context or its values!

func UnwrapV2 added in v2.38.0

func UnwrapV2(ctx huma.Context) *fiberV2.Ctx

UnwrapV2 extracts the underlying Fiber v2 context from a Huma context. If passed a context from a different adapter it will panic. Keep in mind the limitations of the underlying Fiber/fasthttp libraries and how that impacts memory-safety: https://docs.gofiber.io/#zero-allocation. Do not keep references to the underlying context or its values!

Types

This section is empty.

Jump to