humahttprouter

package
v2.38.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var MultipartMaxMemory int64 = 8 * 1024

MultipartMaxMemory is the maximum memory to use when parsing multipart form data.

Functions

func New

func New(r *httprouter.Router, config huma.Config) huma.API

func Unwrap added in v2.30.0

Unwrap extracts the underlying HTTP request and response writer from a Huma context. If passed a context from a different adapter it will panic.

Types

This section is empty.

Jump to