Documentation
¶
Index ¶
- func New(r *fiber.App, config huma.Config) huma.API
- func NewContext(op *huma.Operation, c fiber.Ctx) huma.Context
- func NewV2(r *fiberV2.App, config huma.Config) huma.API
- func NewV2WithGroup(r *fiberV2.App, g fiberV2.Router, config huma.Config) huma.API
- func NewWithGroup(r *fiber.App, g fiber.Router, config huma.Config) huma.API
- func Unwrap(ctx huma.Context) fiber.Ctx
- func UnwrapV2(ctx huma.Context) *fiberV2.Ctx
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewContext ¶ added in v2.39.0
NewContext creates a new Huma context from a fiber context
func NewV2WithGroup ¶ added in v2.38.0
NewV2WithGroup creates a new Huma API using the Fiber v2.x adapter with a route group.
func NewWithGroup ¶ added in v2.11.0
NewWithGroup creates a new Huma API using the Fiber adapter with a route group.
func Unwrap ¶ added in v2.30.0
Unwrap extracts the underlying Fiber context from a Huma context. If passed a context from a different adapter it will panic. Keep in mind the limitations of the underlying Fiber/fasthttp libraries and how that impacts memory-safety: https://docs.gofiber.io/#zero-allocation. Do not keep references to the underlying context or its values!
func UnwrapV2 ¶ added in v2.38.0
UnwrapV2 extracts the underlying Fiber v2 context from a Huma context. If passed a context from a different adapter it will panic. Keep in mind the limitations of the underlying Fiber/fasthttp libraries and how that impacts memory-safety: https://docs.gofiber.io/#zero-allocation. Do not keep references to the underlying context or its values!
Types ¶
This section is empty.