Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var MultipartMaxMemory int64 = 8 * 1024
MultipartMaxMemory is the maximum memory to use when parsing multipart form data.
Functions ¶
func Unwrap ¶ added in v2.30.0
func Unwrap(ctx huma.Context) (*http.Request, http.ResponseWriter, httprouter.Params)
Unwrap extracts the underlying HTTP request and response writer from a Huma context. If passed a context from a different adapter it will panic.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.