Documentation
¶
Index ¶
- Variables
- func New(r *mux.Router, config huma.Config, options ...Option) huma.API
- func NewAdapter(r *mux.Router, options ...Option) huma.Adapter
- func NewContext(op *huma.Operation, r *http.Request, w http.ResponseWriter) huma.Context
- func Unwrap(ctx huma.Context) (*http.Request, http.ResponseWriter)
- type Option
Constants ¶
This section is empty.
Variables ¶
var MultipartMaxMemory int64 = 8 * 1024
MultipartMaxMemory is the maximum memory to use when parsing multipart form data.
Functions ¶
func NewAdapter ¶ added in v2.37.1
NewAdapter creates a new adapter for the given Gorilla mux.
func NewContext ¶ added in v2.37.1
NewContext creates a new Huma context from an HTTP request and response.
Types ¶
Click to show internal directories.
Click to hide internal directories.